@@ -1,4 +1,4 @@
-#include <iostream.h>
+#include "ex.h"
 #include <qpthr/qp.h>
 
 class CreateTest: public QpThread {
@@ -38,7 +38,9 @@ int main(int argc, char *argv[])
 		cout << endl << i << " --------" << endl;
 		for (j = 0; j < concurency; j++) {
 			ct[j] = new CreateTest;
-			ct[j]->Start();
+			if (!ct[j]->IsAlive()) {
+				ct[j]->Start();
+			}
 		}
 		for (j = 0; j < concurency; j++) {
 			delete ct[j];
