@@ -1,4 +1,4 @@
-#include <iostream.h>
+#include "ex.h"
 #include <qpthr/qp.h>
 
 QpTSD tsd;
