@@ -116,6 +116,8 @@ void QpThread::ThrInit(unsigned int prio, unsigned int stack_size)
 	QPERR(pthread_attr_setdetachstate(&attr, PTHREAD_CREATE_DETACHED));
 #ifdef WIN32
 	if (stack_size > 0) {
+#elif FREEBSD
+	if (stack_size > 0) {
 #else
 	if ((int) stack_size >= sysconf(_SC_THREAD_STACK_MIN)) {
 #endif
@@ -364,7 +366,9 @@ unsigned long QpThread::CurrentSeq()
 {
 #ifdef OSF1
 	return pthread_getsequence_np(pthread_self());
-#elif WIN32 // JBR
+#elif WIN32  // JBR
+	return reinterpret_cast<unsigned long>(pthread_self());
+#elif FREEBSD	
 	return reinterpret_cast<unsigned long>(pthread_self());
 #else
 	return pthread_self();
@@ -376,7 +380,9 @@ unsigned long QpThread::ThreadSeq()
 #ifdef OSF1
 	return pthread_getsequence_np(t_id);
 #elif WIN32 // JBR
-  return reinterpret_cast<unsigned long>(t_id);
+  	return reinterpret_cast<unsigned long>(t_id);
+#elif FREEBSD	
+  	return reinterpret_cast<unsigned long>(t_id);
 #else
 	return t_id;
 #endif
